@@ -7,10 +7,7 @@ class QueueClient:
 		self.server = xmlrpclib.Server(xmlrpc_url)
 
 	def pop(self, index=0):
-		try:
-			return self.server.pop(index)
-		except IndexError:
-			return ""
+		return self.server.pop(index)
 
 	def push(self, item):
 		self.server.push(item)
